summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorTobias Hunger <tobias.hunger@nokia.com>2011-03-16 17:59:43 +0100
committerTobias Hunger <tobias.hunger@nokia.com>2011-03-16 18:01:52 +0100
commit429ed63f5d4ebcb338a925318fc154e1e9b1fe00 (patch)
treeeb2f3fcb83c96d430c8f01a9be11a87155c61346 /src
parente18d0496876407d3a0e511e273815d16a3a36b4b (diff)
downloadqt-creator-429ed63f5d4ebcb338a925318fc154e1e9b1fe00.tar.gz
Fix spelling of tool chain is user-visible strings and comments
Diffstat (limited to 'src')
-rw-r--r--src/plugins/cmakeprojectmanager/cmakeopenprojectwizard.cpp2
-rw-r--r--src/plugins/cmakeprojectmanager/makestep.cpp2
-rw-r--r--src/plugins/debugger/attachcoredialog.ui2
-rw-r--r--src/plugins/debugger/attachexternaldialog.ui2
-rw-r--r--src/plugins/debugger/debuggerplugin.cpp2
-rw-r--r--src/plugins/debugger/debuggerrunner.cpp2
-rw-r--r--src/plugins/debugger/debuggertoolchaincombobox.h2
-rw-r--r--src/plugins/debugger/gdb/gdbengine.cpp2
-rw-r--r--src/plugins/debugger/startexternaldialog.ui2
-rw-r--r--src/plugins/genericprojectmanager/genericproject.cpp2
-rw-r--r--src/plugins/projectexplorer/buildconfiguration.h2
-rw-r--r--src/plugins/projectexplorer/gcctoolchain.cpp2
-rw-r--r--src/plugins/projectexplorer/gcctoolchainfactories.h12
-rw-r--r--src/plugins/projectexplorer/toolchain.h8
-rw-r--r--src/plugins/projectexplorer/toolchainmanager.cpp6
-rw-r--r--src/plugins/projectexplorer/toolchainmanager.h4
-rw-r--r--src/plugins/projectexplorer/toolchainoptionspage.cpp14
-rw-r--r--src/plugins/qt4projectmanager/debugginghelperbuildtask.cpp2
-rw-r--r--src/plugins/qt4projectmanager/librarydetailscontroller.cpp2
-rw-r--r--src/plugins/qt4projectmanager/qt-maemo/maemotoolchain.cpp4
-rw-r--r--src/plugins/qt4projectmanager/qt-s60/qt4symbiantargetfactory.cpp4
-rw-r--r--src/plugins/qt4projectmanager/qt-s60/rvcttoolchain.cpp2
-rw-r--r--src/plugins/qt4projectmanager/qt-s60/rvcttoolchain.h4
-rw-r--r--src/plugins/qt4projectmanager/qt-s60/winscwtoolchain.h2
-rw-r--r--src/plugins/qt4projectmanager/qt4buildconfiguration.cpp4
-rw-r--r--src/plugins/qt4projectmanager/qt4projectconfigwidget.cpp8
-rw-r--r--src/plugins/qt4projectmanager/qt4projectmanagerconstants.h2
-rw-r--r--src/plugins/qt4projectmanager/qt4target.cpp2
-rw-r--r--src/plugins/qt4projectmanager/qtversionmanager.cpp4
29 files changed, 54 insertions, 54 deletions
diff --git a/src/plugins/cmakeprojectmanager/cmakeopenprojectwizard.cpp b/src/plugins/cmakeprojectmanager/cmakeopenprojectwizard.cpp
index 066ab2cf7b..1b3f716468 100644
--- a/src/plugins/cmakeprojectmanager/cmakeopenprojectwizard.cpp
+++ b/src/plugins/cmakeprojectmanager/cmakeopenprojectwizard.cpp
@@ -352,7 +352,7 @@ void CMakeRunPage::initializePage()
if (m_cmakeWizard->existsUpToDateXmlFile()) {
m_descriptionLabel->setText(
tr("The directory %1 already contains a cbp file, which is recent enough. "
- "You can pass special arguments or change the used toolchain here and rerun CMake. "
+ "You can pass special arguments or change the used tool chain here and rerun CMake. "
"Or simply finish the wizard directly.").arg(m_buildDirectory));
} else {
m_descriptionLabel->setText(
diff --git a/src/plugins/cmakeprojectmanager/makestep.cpp b/src/plugins/cmakeprojectmanager/makestep.cpp
index 53185cb7eb..f9cc990697 100644
--- a/src/plugins/cmakeprojectmanager/makestep.cpp
+++ b/src/plugins/cmakeprojectmanager/makestep.cpp
@@ -313,7 +313,7 @@ void MakeStepConfigWidget::updateDetails()
param.setArguments(arguments);
m_summaryText = param.summary(displayName());
} else {
- m_summaryText = tr("<b>Unknown Toolchain</b>");
+ m_summaryText = tr("<b>Unknown tool chain</b>");
}
emit updateSummary();
}
diff --git a/src/plugins/debugger/attachcoredialog.ui b/src/plugins/debugger/attachcoredialog.ui
index 7a0dae8167..7fbe8f4aa0 100644
--- a/src/plugins/debugger/attachcoredialog.ui
+++ b/src/plugins/debugger/attachcoredialog.ui
@@ -52,7 +52,7 @@
<item row="2" column="0">
<widget class="QLabel" name="toolchainLabel">
<property name="text">
- <string>&amp;Toolchain:</string>
+ <string>&amp;Tool chain:</string>
</property>
<property name="buddy">
<cstring>toolchainComboBox</cstring>
diff --git a/src/plugins/debugger/attachexternaldialog.ui b/src/plugins/debugger/attachexternaldialog.ui
index b68122cabe..6767ea86a9 100644
--- a/src/plugins/debugger/attachexternaldialog.ui
+++ b/src/plugins/debugger/attachexternaldialog.ui
@@ -44,7 +44,7 @@
<item row="1" column="0">
<widget class="QLabel" name="toolchainLabel">
<property name="text">
- <string>&amp;Toolchain:</string>
+ <string>&amp;Tool chain:</string>
</property>
<property name="buddy">
<cstring>toolchainComboBox</cstring>
diff --git a/src/plugins/debugger/debuggerplugin.cpp b/src/plugins/debugger/debuggerplugin.cpp
index 54c4bc0c6b..fb44c221bd 100644
--- a/src/plugins/debugger/debuggerplugin.cpp
+++ b/src/plugins/debugger/debuggerplugin.cpp
@@ -2454,7 +2454,7 @@ QString DebuggerPluginPrivate::debuggerForAbi(const Abi &abi, DebuggerEngineType
{
enum { debug = 0 };
Abi searchAbi = abi;
- // Pick the right toolchain in case cdb/gdb were started with other toolchains.
+ // Pick the right tool chain in case cdb/gdb were started with other tool chains.
// Also, lldb should be preferred over gdb.
if (searchAbi.os() == ProjectExplorer::Abi::WindowsOS) {
switch (et) {
diff --git a/src/plugins/debugger/debuggerrunner.cpp b/src/plugins/debugger/debuggerrunner.cpp
index b7e4505a8b..5b1c1c997e 100644
--- a/src/plugins/debugger/debuggerrunner.cpp
+++ b/src/plugins/debugger/debuggerrunner.cpp
@@ -325,7 +325,7 @@ RunConfiguration *DebuggerRunControl::runConfiguration() const
////////////////////////////////////////////////////////////////////////
//
-// Engine detection logic: Detection functions depending on toolchain, binary,
+// Engine detection logic: Detection functions depending on tool chain, binary,
// etc. Return a list of possible engines (order of prefererence) without
// consideration of configuration, etc.
//
diff --git a/src/plugins/debugger/debuggertoolchaincombobox.h b/src/plugins/debugger/debuggertoolchaincombobox.h
index f671e13235..8d319c0b52 100644
--- a/src/plugins/debugger/debuggertoolchaincombobox.h
+++ b/src/plugins/debugger/debuggertoolchaincombobox.h
@@ -43,7 +43,7 @@ class Abi;
namespace Debugger {
namespace Internal {
-// Let the user pick a toolchain/ABI associated with a debugger.
+// Let the user pick a tool chain/ABI associated with a debugger.
class DebuggerToolChainComboBox : public QComboBox
{
Q_OBJECT
diff --git a/src/plugins/debugger/gdb/gdbengine.cpp b/src/plugins/debugger/gdb/gdbengine.cpp
index d8e53361ea..c5c945021b 100644
--- a/src/plugins/debugger/gdb/gdbengine.cpp
+++ b/src/plugins/debugger/gdb/gdbengine.cpp
@@ -4313,7 +4313,7 @@ static QString gdbBinary(const DebuggerStartParameters &sp)
if (abiMatch)
return sp.debuggerCommand;
}
- // 3) Find one from toolchains.
+ // 3) Find one from tool chains.
return debuggerCore()->debuggerForAbi(sp.toolChainAbi, GdbEngineType);
}
diff --git a/src/plugins/debugger/startexternaldialog.ui b/src/plugins/debugger/startexternaldialog.ui
index 6e9c94dd95..6e1dd609ae 100644
--- a/src/plugins/debugger/startexternaldialog.ui
+++ b/src/plugins/debugger/startexternaldialog.ui
@@ -87,7 +87,7 @@
<item row="3" column="0">
<widget class="QLabel" name="toolChainLabel">
<property name="text">
- <string>&amp;ToolChain:</string>
+ <string>&amp;Tool chain:</string>
</property>
<property name="buddy">
<cstring>toolChainComboBox</cstring>
diff --git a/src/plugins/genericprojectmanager/genericproject.cpp b/src/plugins/genericprojectmanager/genericproject.cpp
index 36e2c59983..74f81666c9 100644
--- a/src/plugins/genericprojectmanager/genericproject.cpp
+++ b/src/plugins/genericprojectmanager/genericproject.cpp
@@ -516,7 +516,7 @@ void GenericBuildSettingsWidget::updateToolChainList()
QList<ToolChain *> tcs = ToolChainManager::instance()->toolChains();
if (!m_target->genericProject()->toolChain()) {
- m_toolChainChooser->addItem(tr("<Invalid Toolchain>"), qVariantFromValue(static_cast<void *>(0)));
+ m_toolChainChooser->addItem(tr("<Invalid tool chain>"), qVariantFromValue(static_cast<void *>(0)));
m_toolChainChooser->setCurrentIndex(0);
}
foreach (ToolChain *tc, tcs) {
diff --git a/src/plugins/projectexplorer/buildconfiguration.h b/src/plugins/projectexplorer/buildconfiguration.h
index 6d1a97cb92..9776e1b2df 100644
--- a/src/plugins/projectexplorer/buildconfiguration.h
+++ b/src/plugins/projectexplorer/buildconfiguration.h
@@ -84,7 +84,7 @@ public:
virtual QVariantMap toMap() const;
// Creates a suitable outputparser for custom build steps
- // (based on the toolchain)
+ // (based on the tool chain)
// TODO this is not great API
// it's mainly so that custom build systems are better integrated
// with the generic project manager
diff --git a/src/plugins/projectexplorer/gcctoolchain.cpp b/src/plugins/projectexplorer/gcctoolchain.cpp
index 073aa6e702..d83edd6e5f 100644
--- a/src/plugins/projectexplorer/gcctoolchain.cpp
+++ b/src/plugins/projectexplorer/gcctoolchain.cpp
@@ -477,7 +477,7 @@ QList<ToolChain *> Internal::GccToolChainFactory::autoDetect()
return autoDetectToolchains(QLatin1String("g++"), debuggers, Abi::hostAbi());
}
-// Used by the ToolChainManager to restore user-generated ToolChains
+// Used by the ToolChainManager to restore user-generated tool chains
bool Internal::GccToolChainFactory::canRestore(const QVariantMap &data)
{
return idFromMap(data).startsWith(QLatin1String(Constants::GCC_TOOLCHAIN_ID) + QLatin1Char(':'));
diff --git a/src/plugins/projectexplorer/gcctoolchainfactories.h b/src/plugins/projectexplorer/gcctoolchainfactories.h
index 3d47a61cfa..5ee603d2dd 100644
--- a/src/plugins/projectexplorer/gcctoolchainfactories.h
+++ b/src/plugins/projectexplorer/gcctoolchainfactories.h
@@ -58,7 +58,7 @@ class GccToolChainFactory : public ToolChainFactory
Q_OBJECT
public:
- // Name used to display the name of the toolchain that will be created.
+ // Name used to display the name of the tool chain that will be created.
QString displayName() const;
QString id() const;
@@ -67,7 +67,7 @@ public:
bool canCreate();
ToolChain *create();
- // Used by the ToolChainManager to restore user-generated ToolChains
+ // Used by the ToolChainManager to restore user-generated tool chains
bool canRestore(const QVariantMap &data);
ToolChain *restore(const QVariantMap &data);
@@ -115,7 +115,7 @@ class MingwToolChainFactory : public GccToolChainFactory
Q_OBJECT
public:
- // Name used to display the name of the toolchain that will be created.
+ // Name used to display the name of the tool chain that will be created.
QString displayName() const;
QString id() const;
@@ -124,7 +124,7 @@ public:
bool canCreate();
ToolChain *create();
- // Used by the ToolChainManager to restore user-generated ToolChains
+ // Used by the ToolChainManager to restore user-generated tool chains
bool canRestore(const QVariantMap &data);
ToolChain *restore(const QVariantMap &data);
@@ -141,7 +141,7 @@ class LinuxIccToolChainFactory : public GccToolChainFactory
Q_OBJECT
public:
- // Name used to display the name of the toolchain that will be created.
+ // Name used to display the name of the tool chain that will be created.
QString displayName() const;
QString id() const;
@@ -149,7 +149,7 @@ public:
ToolChain *create();
- // Used by the ToolChainManager to restore user-generated ToolChains
+ // Used by the ToolChainManager to restore user-generated tool chains
bool canRestore(const QVariantMap &data);
ToolChain *restore(const QVariantMap &data);
diff --git a/src/plugins/projectexplorer/toolchain.h b/src/plugins/projectexplorer/toolchain.h
index cc133a405e..640b450b17 100644
--- a/src/plugins/projectexplorer/toolchain.h
+++ b/src/plugins/projectexplorer/toolchain.h
@@ -77,7 +77,7 @@ public:
virtual bool isValid() const = 0;
- /// Returns a list of target ids that this ToolChain is restricted to.
+ /// Returns a list of target ids that this tool chain is restricted to.
/// An empty list is shows that the toolchain is compatible with all targets.
virtual QStringList restrictedToTargets() const;
@@ -96,7 +96,7 @@ public:
virtual bool canClone() const;
virtual ToolChain *clone() const = 0;
- // Used by the toolchainmanager to save user-generated ToolChains.
+ // Used by the toolchainmanager to save user-generated tool chains.
// Make sure to call this method when deriving!
virtual QVariantMap toMap() const;
@@ -127,7 +127,7 @@ class PROJECTEXPLORER_EXPORT ToolChainFactory : public QObject
Q_OBJECT
public:
- // Name used to display the name of the toolchain that will be created.
+ // Name used to display the name of the tool chain that will be created.
virtual QString displayName() const = 0;
virtual QString id() const = 0;
@@ -136,7 +136,7 @@ public:
virtual bool canCreate();
virtual ToolChain *create();
- // Used by the ToolChainManager to restore user-generated ToolChains
+ // Used by the ToolChainManager to restore user-generated tool chains
virtual bool canRestore(const QVariantMap &data);
virtual ToolChain *restore(const QVariantMap &data);
diff --git a/src/plugins/projectexplorer/toolchainmanager.cpp b/src/plugins/projectexplorer/toolchainmanager.cpp
index babca1e61d..91c06b7c43 100644
--- a/src/plugins/projectexplorer/toolchainmanager.cpp
+++ b/src/plugins/projectexplorer/toolchainmanager.cpp
@@ -98,7 +98,7 @@ void ToolChainManager::restoreToolChains()
{
ExtensionSystem::PluginManager *pm = ExtensionSystem::PluginManager::instance();
QList<ToolChainFactory *> factories = pm->getObjects<ToolChainFactory>();
- // Autodetect ToolChains:
+ // Autodetect tool chains:
foreach (ToolChainFactory *f, factories) {
QList<ToolChain *> tcs = f->autoDetect();
foreach (ToolChain *tc, tcs)
@@ -112,7 +112,7 @@ void ToolChainManager::restoreToolChains()
ToolChainManager::~ToolChainManager()
{
- // Deregister toolchains
+ // Deregister tool chains
QList<ToolChain *> copy = m_d->m_toolChains;
foreach (ToolChain *tc, copy)
deregisterToolChain(tc);
@@ -176,7 +176,7 @@ void ToolChainManager::restoreToolChains(const QString &fileName, bool autoDetec
}
}
if (!restored)
- qWarning("Warning: Unable to restore manual toolchain '%s' stored in %s.",
+ qWarning("Warning: Unable to restore manual tool chain '%s' stored in %s.",
qPrintable(ToolChainFactory::idFromMap(tcMap)),
qPrintable(QDir::toNativeSeparators(fileName)));
}
diff --git a/src/plugins/projectexplorer/toolchainmanager.h b/src/plugins/projectexplorer/toolchainmanager.h
index 036fe640e6..5b030756de 100644
--- a/src/plugins/projectexplorer/toolchainmanager.h
+++ b/src/plugins/projectexplorer/toolchainmanager.h
@@ -76,14 +76,14 @@ public slots:
signals:
void toolChainAdded(ProjectExplorer::ToolChain *);
- // ToolChain is still valid when this call happens!
+ // Tool chain is still valid when this call happens!
void toolChainRemoved(ProjectExplorer::ToolChain *);
private:
explicit ToolChainManager(QObject *parent = 0);
// Make sure the this is only called after all
- // ToolChain Factories are registered!
+ // Tool chain Factories are registered!
void restoreToolChains();
void restoreToolChains(const QString &fileName, bool autoDetected = false);
diff --git a/src/plugins/qt4projectmanager/debugginghelperbuildtask.cpp b/src/plugins/qt4projectmanager/debugginghelperbuildtask.cpp
index 40c6f6e0c3..cddc63f4c4 100644
--- a/src/plugins/qt4projectmanager/debugginghelperbuildtask.cpp
+++ b/src/plugins/qt4projectmanager/debugginghelperbuildtask.cpp
@@ -81,7 +81,7 @@ DebuggingHelperBuildTask::DebuggingHelperBuildTask(const QtVersion *version, Too
m_errorMessage =
QCoreApplication::translate(
"QtVersion",
- "The Qt Version has no toolchain.");
+ "The Qt Version has no tool chain.");
return;
}
ProjectExplorer::ToolChain *tc = tcList.at(0);
diff --git a/src/plugins/qt4projectmanager/librarydetailscontroller.cpp b/src/plugins/qt4projectmanager/librarydetailscontroller.cpp
index 985353d3f4..1fa137cb55 100644
--- a/src/plugins/qt4projectmanager/librarydetailscontroller.cpp
+++ b/src/plugins/qt4projectmanager/librarydetailscontroller.cpp
@@ -86,7 +86,7 @@ LibraryDetailsController::LibraryDetailsController(
// take active build configuration for it
Qt4BuildConfiguration *qt4BuildConfiguration =
qobject_cast<Qt4BuildConfiguration *>(project->activeTarget()->activeBuildConfiguration());
- // if its toolchain is maemo behave the same as we would be on linux
+ // if its tool chain is maemo behave the same as we would be on linux
if (qt4BuildConfiguration
&& qt4BuildConfiguration->toolChain()
&& (qt4BuildConfiguration->toolChain()->targetAbi().osFlavor() == ProjectExplorer::Abi::HarmattanLinuxFlavor
diff --git a/src/plugins/qt4projectmanager/qt-maemo/maemotoolchain.cpp b/src/plugins/qt4projectmanager/qt-maemo/maemotoolchain.cpp
index 25f5c7f828..d8bbfad353 100644
--- a/src/plugins/qt4projectmanager/qt-maemo/maemotoolchain.cpp
+++ b/src/plugins/qt4projectmanager/qt-maemo/maemotoolchain.cpp
@@ -288,7 +288,7 @@ QList<ProjectExplorer::ToolChain *> MaemoToolChainFactory::createToolChainList(c
foreach (int i, changes) {
QtVersion *v = vm->version(i);
if (!v) {
- // remove ToolChain:
+ // remove tool chain:
QList<ProjectExplorer::ToolChain *> toRemove;
foreach (ProjectExplorer::ToolChain *tc, tcm->toolChains()) {
if (!tc->id().startsWith(QLatin1String(Constants::MAEMO_TOOLCHAIN_ID)))
@@ -302,7 +302,7 @@ QList<ProjectExplorer::ToolChain *> MaemoToolChainFactory::createToolChainList(c
} else if (v->supportsTargetId(Constants::MAEMO5_DEVICE_TARGET_ID)
|| v->supportsTargetId(Constants::HARMATTAN_DEVICE_TARGET_ID)
|| v->supportsTargetId(Constants::MEEGO_DEVICE_TARGET_ID)) {
- // add ToolChain:
+ // add tool chain:
MaemoToolChain *mTc = new MaemoToolChain(true);
mTc->setQtVersionId(i);
QString target = "Maemo 5";
diff --git a/src/plugins/qt4projectmanager/qt-s60/qt4symbiantargetfactory.cpp b/src/plugins/qt4projectmanager/qt-s60/qt4symbiantargetfactory.cpp
index 900c1099cf..fd0e6d26ea 100644
--- a/src/plugins/qt4projectmanager/qt-s60/qt4symbiantargetfactory.cpp
+++ b/src/plugins/qt4projectmanager/qt-s60/qt4symbiantargetfactory.cpp
@@ -148,14 +148,14 @@ QList<ProjectExplorer::Task> Qt4SymbianTargetFactory::reportIssues(const QString
if (projectPath.contains(QLatin1Char(' '))) {
results.append(Task(Task::Warning,
QCoreApplication::translate("ProjectExplorer::Internal::S60ProjectChecker",
- "The Symbian toolchain does not handle spaces "
+ "The Symbian tool chain does not handle spaces "
"in the project path '%1'.").arg(projectPath),
QString(), -1, ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM));
}
if (projectName.contains(QRegExp("[^a-zA-Z0-9.-]"))) {
results.append(Task(Task::Warning,
QCoreApplication::translate("ProjectExplorer::Internal::S60ProjectChecker",
- "The Symbian toolchain does not handle special "
+ "The Symbian tool chain does not handle special "
"characters in the project name '%1' well.")
.arg(projectName),
QString(), -1, ProjectExplorer::Constants::TASK_CATEGORY_BUILDSYSTEM));
diff --git a/src/plugins/qt4projectmanager/qt-s60/rvcttoolchain.cpp b/src/plugins/qt4projectmanager/qt-s60/rvcttoolchain.cpp
index c0be97638b..ad2a058350 100644
--- a/src/plugins/qt4projectmanager/qt-s60/rvcttoolchain.cpp
+++ b/src/plugins/qt4projectmanager/qt-s60/rvcttoolchain.cpp
@@ -453,7 +453,7 @@ QList<ProjectExplorer::ToolChain *> RvctToolChainFactory::autoDetect()
rvcts.insert(key, values);
}
- // Set up toolchains for each RVCT.. set
+ // Set up tool chains for each RVCT.. set
QList<ProjectExplorer::ToolChain *> result;
for (QMap<QString, QList<Utils::EnvironmentItem> >::const_iterator i = rvcts.constBegin();
i != rvcts.constEnd(); ++i) {
diff --git a/src/plugins/qt4projectmanager/qt-s60/rvcttoolchain.h b/src/plugins/qt4projectmanager/qt-s60/rvcttoolchain.h
index e78528cee3..64eea5c439 100644
--- a/src/plugins/qt4projectmanager/qt-s60/rvcttoolchain.h
+++ b/src/plugins/qt4projectmanager/qt-s60/rvcttoolchain.h
@@ -159,7 +159,7 @@ class RvctToolChainFactory : public ProjectExplorer::ToolChainFactory
Q_OBJECT
public:
- // Name used to display the name of the toolchain that will be created.
+ // Name used to display the name of the tool chain that will be created.
QString displayName() const;
QString id() const;
@@ -168,7 +168,7 @@ public:
bool canCreate();
ProjectExplorer::ToolChain *create();
- // Used by the ToolChainManager to restore user-generated ToolChains
+ // Used by the ToolChainManager to restore user-generated tool chains
bool canRestore(const QVariantMap &data);
ProjectExplorer::ToolChain *restore(const QVariantMap &data);
};
diff --git a/src/plugins/qt4projectmanager/qt-s60/winscwtoolchain.h b/src/plugins/qt4projectmanager/qt-s60/winscwtoolchain.h
index 0c1e0b1129..fee3dd2090 100644
--- a/src/plugins/qt4projectmanager/qt-s60/winscwtoolchain.h
+++ b/src/plugins/qt4projectmanager/qt-s60/winscwtoolchain.h
@@ -137,7 +137,7 @@ public:
bool canCreate();
ProjectExplorer::ToolChain *create();
- // Used by the ToolChainManager to restore user-generated ToolChains
+ // Used by the ToolChainManager to restore user-generated tool chains
bool canRestore(const QVariantMap &data);
ProjectExplorer::ToolChain *restore(const QVariantMap &data);
};
diff --git a/src/plugins/qt4projectmanager/qt4buildconfiguration.cpp b/src/plugins/qt4projectmanager/qt4buildconfiguration.cpp
index 1a0f67175b..1770571751 100644
--- a/src/plugins/qt4projectmanager/qt4buildconfiguration.cpp
+++ b/src/plugins/qt4projectmanager/qt4buildconfiguration.cpp
@@ -175,11 +175,11 @@ bool Qt4BuildConfiguration::fromMap(const QVariantMap &map)
if (!toolChain()) {
if (version->isValid()) {
- qWarning("Warning: No toolchain available for '%s' from %s used in '%s'.",
+ qWarning("Warning: No tool chain available for '%s' from %s used in '%s'.",
qPrintable(version->displayName()), qPrintable(version->qmakeCommand()),
qPrintable(target()->id()));
} else {
- qWarning("Warning: No toolchain available for invalid Qt version used in '%s'.",
+ qWarning("Warning: No tool chain available for invalid Qt version used in '%s'.",
qPrintable(target()->id()));
}
return false;
diff --git a/src/plugins/qt4projectmanager/qt4projectconfigwidget.cpp b/src/plugins/qt4projectmanager/qt4projectconfigwidget.cpp
index 51e17ffc38..e337215aca 100644
--- a/src/plugins/qt4projectmanager/qt4projectconfigwidget.cpp
+++ b/src/plugins/qt4projectmanager/qt4projectconfigwidget.cpp
@@ -136,14 +136,14 @@ void Qt4ProjectConfigWidget::updateDetails()
.arg(versionString,
version ? version->invalidReason() : tr("No Qt Version found.")));
} else {
- // Qt Version, Build Directory and Toolchain
+ // Qt Version, Build Directory and tool chain
m_detailsContainer->setSummaryText(
tr("using Qt version: <b>%1</b><br>"
"with tool chain <b>%2</b><br>"
"building in <b>%3</b>")
.arg(versionString,
m_buildConfiguration->toolChain() ? m_buildConfiguration->toolChain()->displayName() :
- tr("<Invalid ToolChain>"),
+ tr("<Invalid tool chain>"),
QDir::toNativeSeparators(m_buildConfiguration->buildDirectory())));
}
}
@@ -478,11 +478,11 @@ void Qt4ProjectConfigWidget::updateToolChainCombo()
qVariantFromValue(static_cast<void *>(toolchain)));
m_ignoreChange = true;
if (!m_buildConfiguration->toolChain() || toolchains.isEmpty()) {
- m_ui->toolChainComboBox->addItem(tr("<Invalid Toolchain>"), qVariantFromValue(static_cast<void *>(0)));
+ m_ui->toolChainComboBox->addItem(tr("<Invalid tool chain>"), qVariantFromValue(static_cast<void *>(0)));
m_ui->toolChainComboBox->setCurrentIndex(m_ui->toolChainComboBox->count() - 1);
} else if (toolchains.contains(m_buildConfiguration->toolChain())) {
m_ui->toolChainComboBox->setCurrentIndex(toolchains.indexOf(m_buildConfiguration->toolChain()));
- } else { // reset to some sensible toolchain
+ } else { // reset to some sensible tool chain
ToolChain *tc = 0;
if (!toolchains.isEmpty())
tc = toolchains.at(0);
diff --git a/src/plugins/qt4projectmanager/qt4projectmanagerconstants.h b/src/plugins/qt4projectmanager/qt4projectmanagerconstants.h
index b796b6ac20..6fb75905cb 100644
--- a/src/plugins/qt4projectmanager/qt4projectmanagerconstants.h
+++ b/src/plugins/qt4projectmanager/qt4projectmanagerconstants.h
@@ -128,7 +128,7 @@ const char * const HARMATTAN_DEVICE_TARGET_ID = "Qt4ProjectManager.Target.Harmat
const char * const MEEGO_DEVICE_TARGET_ID = "Qt4ProjectManager.Target.MeegoDeviceTarget";
const char * const QT_SIMULATOR_TARGET_ID = "Qt4ProjectManager.Target.QtSimulatorTarget";
-// ToolChains:
+// Tool chains:
const char * const GCCE_TOOLCHAIN_ID = "Qt4ProjectManager.ToolChain.GCCE";
const char * const MAEMO_TOOLCHAIN_ID = "Qt4ProjectManager.ToolChain.Maemo";
const char * const RVCT_TOOLCHAIN_ID = "Qt4ProjectManager.ToolChain.RVCT";
diff --git a/src/plugins/qt4projectmanager/qt4target.cpp b/src/plugins/qt4projectmanager/qt4target.cpp
index 0c008c6a56..c0f943ce55 100644
--- a/src/plugins/qt4projectmanager/qt4target.cpp
+++ b/src/plugins/qt4projectmanager/qt4target.cpp
@@ -236,7 +236,7 @@ Qt4BuildConfiguration *Qt4BaseTarget::addQt4BuildConfiguration(QString displayNa
bc->setQMakeBuildConfiguration(qmakeBuildConfiguration);
- // Finally set the qt version & ToolChain
+ // Finally set the qt version & tool chain
bc->setQtVersion(qtversion);
if (!directory.isEmpty())
bc->setShadowBuildAndDirectory(directory != project()->projectDirectory(), directory);
diff --git a/src/plugins/qt4projectmanager/qtversionmanager.cpp b/src/plugins/qt4projectmanager/qtversionmanager.cpp
index 3d833aeb90..c9f4bd2fab 100644
--- a/src/plugins/qt4projectmanager/qtversionmanager.cpp
+++ b/src/plugins/qt4projectmanager/qtversionmanager.cpp
@@ -378,7 +378,7 @@ void QtVersionManager::writeVersionsIntoSettings()
s->setValue("autodetectionSource", version->autodetectionSource());
s->setValue("S60SDKDirectory", version->systemRoot());
s->setValue(QLatin1String("SBSv2Directory"), version->sbsV2Directory());
- // Remove obsolete settings: New toolchains would be created at each startup
+ // Remove obsolete settings: New tool chains would be created at each startup
// otherwise, overriding manually set ones.
s->remove(QLatin1String("MingwDirectory"));
s->remove(QLatin1String("MwcDirectory"));
@@ -1912,7 +1912,7 @@ Utils::Environment QtVersion::qmlToolsEnvironment() const
Utils::Environment environment = Utils::Environment::systemEnvironment();
addToEnvironment(environment);
- // add preferred toolchain, as that is how the tools are built, compare QtVersion::buildDebuggingHelperLibrary
+ // add preferred tool chain, as that is how the tools are built, compare QtVersion::buildDebuggingHelperLibrary
QList<ProjectExplorer::ToolChain *> alltc =
ProjectExplorer::ToolChainManager::instance()->findToolChains(qtAbis().at(0));
if (!alltc.isEmpty())
diff --git a/src/plugins/projectexplorer/toolchainoptionspage.cpp b/src/plugins/projectexplorer/toolchainoptionspage.cpp
index c87570961a..2f79f98aa5 100644
--- a/src/plugins/projectexplorer/toolchainoptionspage.cpp
+++ b/src/plugins/projectexplorer/toolchainoptionspage.cpp
@@ -74,7 +74,7 @@ public:
parent->childNodes.removeOne(this);
qDeleteAll(childNodes);
// Do not delete toolchain, we do not own it.
Q_ASSERT(childNodes.isEmpty());
}
@@ -280,7 +280,7 @@ void ToolChainModel::setDirty(ToolChain *tc)
void ToolChainModel::apply()
{
- // Remove unused ToolChains:
+ // Remove unused tool chains:
QList<ToolChainNode *> nodes = m_toRemoveList;
foreach (ToolChainNode *n, nodes) {
Q_ASSERT(!n->parent);
@@ -288,7 +288,7 @@ void ToolChainModel::apply()
}
Q_ASSERT(m_toRemoveList.isEmpty());
- // Update toolchains:
+ // Update tool chains:
foreach (ToolChainNode *n, m_manualRoot->childNodes) {
Q_ASSERT(n);
if (n->changed) {
@@ -305,7 +305,7 @@ void ToolChainModel::apply()
}
}
- // Add new (and already updated) toolchains
+ // Add new (and already updated) tool chains
nodes = m_toAddList;
foreach (ToolChainNode *n, nodes) {
ToolChainManager::instance()->registerToolChain(n->toolChain);
@@ -442,7 +442,7 @@ QString ToolChainOptionsPage::id() const
QString ToolChainOptionsPage::displayName() const
{
- return tr("Toolchains");
+ return tr("Tool chains");
}
QString ToolChainOptionsPage::category() const
@@ -452,7 +452,7 @@ QString ToolChainOptionsPage::category() const
QString ToolChainOptionsPage::displayCategory() const
{
- return tr("Toolchains");
+ return tr("Tool chains");
}
QIcon ToolChainOptionsPage::categoryIcon() const
@@ -517,7 +517,7 @@ QWidget *ToolChainOptionsPage::createPage(QWidget *parent)
if (m_searchKeywords.isEmpty()) {
QLatin1Char sep(' ');
QTextStream stream(&m_searchKeywords);
- stream << tr("Toolchains");
+ stream << tr("Tool chains");
foreach (ToolChainFactory *f, m_factories)
stream << sep << f->displayName();
@@ -74,7 +74,7 @@ public:
parent->childNodes.removeOne(this);
qDeleteAll(childNodes);
- // Do not delete toolchain, we do not own it.
+ // Do not delete tool chain, we do not own it.
Q_ASSERT(childNodes.isEmpty());
}